@@ -1,15 +1,15 @@
 /*
  * params.h
  *
- * (c) 1999, 2000, 2001 Alexey Vyskubov <alexey@pepper.spb.ru>
+ * (c) 1998-2002 Alexey Vyskubov <alexey@mawhrin.net>
  *
  */
 
 #ifndef PARAMS_H
 #define PARAMS_H
 
-#ifdef PROPLIST
-#include <proplist.h>
+#ifdef HAVE_WINGS_WUTIL_H 
+#include <WINGs/WUtil.h> 
 
 #ifdef WMAKER
 #define DEFAULTS_FILE "~/GNUstep/Defaults/FOOkb"
@@ -17,7 +17,7 @@
 #define DEFAULTS_FILE "~/.fookb"
 #endif				/* WMAKER */
 
-#endif				/* PROPLIST */
+#endif				/* HAVE_WINGS_WUTIL_H */
 
 #include <X11/Xlib.h>		/* X Window standard header */
 #include <X11/Xresource.h>	/* X resource manager stuff */
